from _typeshed import Incomplete
from typing import Final, NamedTuple

from reportlab.pdfbase import pdfdoc, pdfmetrics

__version__: Final[str]

class TTFError(pdfdoc.PDFError): ...

def SUBSETN(n, table=...): ...
def makeToUnicodeCMap(fontname, subset): ...
def splice(stream, offset, value): ...

GF_ARG_1_AND_2_ARE_WORDS: Incomplete
GF_ARGS_ARE_XY_VALUES: Incomplete
GF_ROUND_XY_TO_GRID: Incomplete
GF_WE_HAVE_A_SCALE: Incomplete
GF_RESERVED: Incomplete
GF_MORE_COMPONENTS: Incomplete
GF_WE_HAVE_AN_X_AND_Y_SCALE: Incomplete
GF_WE_HAVE_A_TWO_BY_TWO: Incomplete
GF_WE_HAVE_INSTRUCTIONS: Incomplete
GF_USE_MY_METRICS: Incomplete
GF_OVERLAP_COMPOUND: Incomplete
GF_SCALED_COMPONENT_OFFSET: Incomplete
GF_UNSCALED_COMPONENT_OFFSET: Incomplete

def TTFOpenFile(fn): ...

class TTFontParser:
    ttfVersions: Incomplete
    ttcVersions: Incomplete
    fileKind: str
    validate: Incomplete
    subfontNameX: bytes
    def __init__(self, file, validate: int = 0, subfontIndex: int = 0) -> None: ...
    ttcVersion: Incomplete
    numSubfonts: Incomplete
    subfontOffsets: Incomplete
    def readTTCHeader(self) -> None: ...
    def getSubfont(self, subfontIndex) -> None: ...
    numTables: Incomplete
    searchRange: Incomplete
    entrySelector: Incomplete
    rangeShift: Incomplete
    table: Incomplete
    tables: Incomplete
    def readTableDirectory(self) -> None: ...
    version: Incomplete
    def readHeader(self): ...
    filename: Incomplete
    def readFile(self, f) -> None: ...
    def checksumTables(self) -> None: ...
    def checksumFile(self) -> None: ...
    def get_table_pos(self, tag): ...
    def seek(self, pos) -> None: ...
    def skip(self, delta) -> None: ...
    def seek_table(self, tag, offset_in_table: int = 0): ...
    def read_tag(self): ...
    def get_chunk(self, pos, length): ...
    def read_uint8(self): ...
    def read_ushort(self): ...
    def read_ulong(self): ...
    def read_short(self): ...
    def get_ushort(self, pos): ...
    def get_ulong(self, pos): ...
    def get_table(self, tag): ...

class TTFontMaker:
    tables: Incomplete
    def __init__(self) -> None: ...
    def add(self, tag, data) -> None: ...
    def makeStream(self): ...

class CMapFmt2SubHeader(NamedTuple):
    firstCode: Incomplete
    entryCount: Incomplete
    idDelta: Incomplete
    idRangeOffset: Incomplete

class TTFNameBytes(bytes):
    ustr: Incomplete
    def __new__(cls, b, enc: str = "utf8"): ...

class TTFontFile(TTFontParser):
    def __init__(self, file, charInfo: int = 1, validate: int = 0, subfontIndex: int = 0) -> None: ...
    name: Incomplete
    familyName: Incomplete
    styleName: Incomplete
    fullName: Incomplete
    uniqueFontID: Incomplete
    fontRevision: Incomplete
    unitsPerEm: Incomplete
    bbox: Incomplete
    ascent: Incomplete
    descent: Incomplete
    capHeight: Incomplete
    stemV: Incomplete
    italicAngle: Incomplete
    underlinePosition: Incomplete
    underlineThickness: Incomplete
    flags: Incomplete
    numGlyphs: Incomplete
    charToGlyph: Incomplete
    defaultWidth: Incomplete
    charWidths: Incomplete
    hmetrics: Incomplete
    glyphPos: Incomplete
    def extractInfo(self, charInfo: int = 1): ...
    def makeSubset(self, subset): ...

FF_FIXED: Incomplete
FF_SERIF: Incomplete
FF_SYMBOLIC: Incomplete
FF_SCRIPT: Incomplete
FF_NONSYMBOLIC: Incomplete
FF_ITALIC: Incomplete
FF_ALLCAP: Incomplete
FF_SMALLCAP: Incomplete
FF_FORCEBOLD: Incomplete

class TTFontFace(TTFontFile, pdfmetrics.TypeFace):
    def __init__(self, filename, validate: int = 0, subfontIndex: int = 0) -> None: ...
    def getCharWidth(self, code): ...
    def addSubsetObjects(self, doc, fontname, subset): ...

class TTEncoding:
    name: str
    def __init__(self) -> None: ...

class TTFont:
    class State:
        namePrefix: str
        nextCode: int
        internalName: Incomplete
        frozen: int
        subsets: Incomplete
        def __init__(self, asciiReadable: Incomplete | None = None, ttf: Incomplete | None = None) -> None: ...

    fontName: Incomplete
    face: Incomplete
    encoding: Incomplete
    state: Incomplete
    def __init__(
        self, name, filename, validate: int = 0, subfontIndex: int = 0, asciiReadable: Incomplete | None = None
    ) -> None: ...
    def stringWidth(self, text, size, encoding: str = "utf8"): ...
    def splitString(self, text, doc, encoding: str = "utf-8"): ...
    def getSubsetInternalName(self, subset, doc): ...
    def addObjects(self, doc) -> None: ...



from setuptools import setup

name = "types-reportlab"
description = "Typing stubs for reportlab"
long_description = '''
## Typing stubs for reportlab

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`reportlab`](https://github.com/MrBitBucket/reportlab-mirror) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
PyCharm, etc. to check code that uses
`reportlab`.

This version of `types-reportlab` aims to provide accurate annotations
for `reportlab==4.2.4`.
The source for this package can be found at
https://github.com/python/typeshed/tree/main/stubs/reportlab. All fixes for
types and metadata should be contributed there.

See https://github.com/python/typeshed/blob/main/README.md for more details.
This package was generated from typeshed commit
[`6990bb64a964ab01f82979e1cda81e0941bf5579`](https://github.com/python/typeshed/commit/6990bb64a964ab01f82979e1cda81e0941bf5579) and was tested
with mypy 1.11.1, pyright 1.1.382.post1, and
pytype 2024.9.13.
'''.lstrip()

setup(name=name,
      version="4.2.4.20240930",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      project_urls={
          "GitHub": "https://github.com/python/typeshed",
          "Changes": "https://github.com/typeshed-internal/stub_uploader/blob/main/data/changelogs/reportlab.md",
          "Issue tracker": "https://github.com/python/typeshed/issues",
          "Chat": "https://gitter.im/python/typing",
      },
      install_requires=[],
      packages=['reportlab-stubs'],
      package_data={'reportlab-stubs': ['__init__.pyi', 'graphics/__init__.pyi', 'graphics/barcode/__init__.pyi', 'graphics/barcode/code128.pyi', 'graphics/barcode/code39.pyi', 'graphics/barcode/code93.pyi', 'graphics/barcode/common.pyi', 'graphics/barcode/dmtx.pyi', 'graphics/barcode/eanbc.pyi', 'graphics/barcode/ecc200datamatrix.pyi', 'graphics/barcode/fourstate.pyi', 'graphics/barcode/lto.pyi', 'graphics/barcode/qr.pyi', 'graphics/barcode/qrencoder.pyi', 'graphics/barcode/usps.pyi', 'graphics/barcode/usps4s.pyi', 'graphics/barcode/widgets.pyi', 'graphics/charts/__init__.pyi', 'graphics/charts/areas.pyi', 'graphics/charts/axes.pyi', 'graphics/charts/barcharts.pyi', 'graphics/charts/dotbox.pyi', 'graphics/charts/doughnut.pyi', 'graphics/charts/legends.pyi', 'graphics/charts/linecharts.pyi', 'graphics/charts/lineplots.pyi', 'graphics/charts/markers.pyi', 'graphics/charts/piecharts.pyi', 'graphics/charts/slidebox.pyi', 'graphics/charts/spider.pyi', 'graphics/charts/textlabels.pyi', 'graphics/charts/utils.pyi', 'graphics/charts/utils3d.pyi', 'graphics/renderPDF.pyi', 'graphics/renderPM.pyi', 'graphics/renderPS.pyi', 'graphics/renderSVG.pyi', 'graphics/renderbase.pyi', 'graphics/samples/__init__.pyi', 'graphics/samples/bubble.pyi', 'graphics/samples/clustered_bar.pyi', 'graphics/samples/clustered_column.pyi', 'graphics/samples/excelcolors.pyi', 'graphics/samples/exploded_pie.pyi', 'graphics/samples/filled_radar.pyi', 'graphics/samples/line_chart.pyi', 'graphics/samples/linechart_with_markers.pyi', 'graphics/samples/radar.pyi', 'graphics/samples/runall.pyi', 'graphics/samples/scatter.pyi', 'graphics/samples/scatter_lines.pyi', 'graphics/samples/scatter_lines_markers.pyi', 'graphics/samples/simple_pie.pyi', 'graphics/samples/stacked_bar.pyi', 'graphics/samples/stacked_column.pyi', 'graphics/shapes.pyi', 'graphics/svgpath.pyi', 'graphics/transform.pyi', 'graphics/utils.pyi', 'graphics/widgetbase.pyi', 'graphics/widgets/__init__.pyi', 'graphics/widgets/adjustableArrow.pyi', 'graphics/widgets/eventcal.pyi', 'graphics/widgets/flags.pyi', 'graphics/widgets/grids.pyi', 'graphics/widgets/markers.pyi', 'graphics/widgets/signsandsymbols.pyi', 'graphics/widgets/table.pyi', 'lib/PyFontify.pyi', 'lib/__init__.pyi', 'lib/abag.pyi', 'lib/arciv.pyi', 'lib/attrmap.pyi', 'lib/boxstuff.pyi', 'lib/codecharts.pyi', 'lib/colors.pyi', 'lib/corp.pyi', 'lib/enums.pyi', 'lib/extformat.pyi', 'lib/fontfinder.pyi', 'lib/fonts.pyi', 'lib/formatters.pyi', 'lib/geomutils.pyi', 'lib/logger.pyi', 'lib/normalDate.pyi', 'lib/pagesizes.pyi', 'lib/pdfencrypt.pyi', 'lib/pygments2xpre.pyi', 'lib/randomtext.pyi', 'lib/rl_accel.pyi', 'lib/rl_safe_eval.pyi', 'lib/rltempfile.pyi', 'lib/rparsexml.pyi', 'lib/sequencer.pyi', 'lib/styles.pyi', 'lib/testutils.pyi', 'lib/textsplit.pyi', 'lib/units.pyi', 'lib/utils.pyi', 'lib/validators.pyi', 'lib/yaml.pyi', 'pdfbase/__init__.pyi', 'pdfbase/acroform.pyi', 'pdfbase/cidfonts.pyi', 'pdfbase/pdfdoc.pyi', 'pdfbase/pdfform.pyi', 'pdfbase/pdfmetrics.pyi', 'pdfbase/pdfpattern.pyi', 'pdfbase/pdfutils.pyi', 'pdfbase/rl_codecs.pyi', 'pdfbase/ttfonts.pyi', 'pdfgen/__init__.pyi', 'pdfgen/canvas.pyi', 'pdfgen/pathobject.pyi', 'pdfgen/pdfgeom.pyi', 'pdfgen/pdfimages.pyi', 'pdfgen/textobject.pyi', 'platypus/__init__.pyi', 'platypus/doctemplate.pyi', 'platypus/figures.pyi', 'platypus/flowables.pyi', 'platypus/frames.pyi', 'platypus/multicol.pyi', 'platypus/para.pyi', 'platypus/paragraph.pyi', 'platypus/paraparser.pyi', 'platypus/tableofcontents.pyi', 'platypus/tables.pyi', 'platypus/xpreformatted.pyi', 'rl_config.pyi', 'rl_settings.pyi', 'METADATA.toml', 'py.typed']},
      license="Apache-2.0",
      python_requires=">=3.8",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Programming Language :: Python :: 3",
          "Typing :: Stubs Only",
      ]
)
